From e80484a9d3a6897984a2bc1f80df55d590e2e85b Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Mon, 22 Aug 2022 16:51:52 +0200
Subject: [PATCH 1/5] Remove unnecessary casts in free() and pfree()

---
 contrib/sepgsql/label.c        | 8 ++++----
 src/backend/utils/fmgr/dfmgr.c | 6 +++---
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/contrib/sepgsql/label.c b/contrib/sepgsql/label.c
index e4c98b7eae..6e7c0d7cff 100644
--- a/contrib/sepgsql/label.c
+++ b/contrib/sepgsql/label.c
@@ -662,28 +662,28 @@ quote_object_name(const char *src1, const char *src2,
 		temp = quote_identifier(src1);
 		appendStringInfoString(&result, temp);
 		if (src1 != temp)
-			pfree((void *) temp);
+			pfree(temp);
 	}
 	if (src2)
 	{
 		temp = quote_identifier(src2);
 		appendStringInfo(&result, ".%s", temp);
 		if (src2 != temp)
-			pfree((void *) temp);
+			pfree(temp);
 	}
 	if (src3)
 	{
 		temp = quote_identifier(src3);
 		appendStringInfo(&result, ".%s", temp);
 		if (src3 != temp)
-			pfree((void *) temp);
+			pfree(temp);
 	}
 	if (src4)
 	{
 		temp = quote_identifier(src4);
 		appendStringInfo(&result, ".%s", temp);
 		if (src4 != temp)
-			pfree((void *) temp);
+			pfree(temp);
 	}
 	return result.data;
 }
diff --git a/src/backend/utils/fmgr/dfmgr.c b/src/backend/utils/fmgr/dfmgr.c
index 08fd7e1264..6ae6fc1556 100644
--- a/src/backend/utils/fmgr/dfmgr.c
+++ b/src/backend/utils/fmgr/dfmgr.c
@@ -240,7 +240,7 @@ internal_load_library(const char *libname)
 		if (file_scanner->handle == NULL)
 		{
 			load_error = dlerror();
-			free((char *) file_scanner);
+			free(file_scanner);
 			/* errcode_for_file_access might not be appropriate here? */
 			ereport(ERROR,
 					(errcode_for_file_access(),
@@ -263,7 +263,7 @@ internal_load_library(const char *libname)
 
 				/* try to close library */
 				dlclose(file_scanner->handle);
-				free((char *) file_scanner);
+				free(file_scanner);
 
 				/* issue suitable complaint */
 				incompatible_module_error(libname, &module_magic_data);
@@ -273,7 +273,7 @@ internal_load_library(const char *libname)
 		{
 			/* try to close library */
 			dlclose(file_scanner->handle);
-			free((char *) file_scanner);
+			free(file_scanner);
 			/* complain */
 			ereport(ERROR,
 					(errmsg("incompatible library \"%s\": missing magic block",
-- 
2.37.1

